import { Component, ChangeDetectionStrategy, Input } from '@angular/core';
import { RebirthNGConfig } from '../rebirth-ng.config';
import { DocumentRef } from '../window-ref/document-ref.service';
var EllipsisComponent = (function () {
    function EllipsisComponent(rebirthNGConfig, documentRef) {
        this.documentRef = documentRef;
        this.fullText = '';
        this.ellipsisText = '';
        this.html = false;
        this.length = rebirthNGConfig.ellipsis.length;
        this.placement = rebirthNGConfig.ellipsis.placement;
    }
    Object.defineProperty(EllipsisComponent.prototype, "max", {
        set: function (length) {
            this.length = length;
            this.ellipsis();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(EllipsisComponent.prototype, "text", {
        set: function (text) {
            this.fullText = text || '';
            this.ellipsis();
        },
        enumerable: true,
        configurable: true
    });
    EllipsisComponent.prototype.ellipsis = function () {
        var text = this.html ? this.unCodeHtml(this.fullText) : this.fullText;
        this.ellipsisText = text.length > this.length ? text.substr(0, this.length) : '';
    };
    EllipsisComponent.prototype.unCodeHtml = function (text) {
        var $div = this.documentRef.createElement('div');
        $div.innerHTML = text;
        text = $div.innerText;
        return text;
    };
    EllipsisComponent.decorators = [
        { type: Component, args: [{
                    selector: 're-ellipsis',
                    template: "\n    <span *ngIf=\"ellipsisText\" [reTooltip]=\"fullText\" [placement]=\"placement\">{{ellipsisText}}...</span> <span *ngIf=\"!html && !ellipsisText\">{{fullText}}</span> <span *ngIf=\"html && !ellipsisText\" [innerHTML]=\"fullText\"></span>\n  ",
                    styles: ["\n    :host{display:inline-block;cursor:default}\n  "],
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    exportAs: 'ellipsis'
                },] },
    ];
    /** @nocollapse */
    EllipsisComponent.ctorParameters = function () { return [
        { type: RebirthNGConfig, },
        { type: DocumentRef, },
    ]; };
    EllipsisComponent.propDecorators = {
        "placement": [{ type: Input },],
        "html": [{ type: Input },],
        "max": [{ type: Input },],
        "text": [{ type: Input },],
    };
    return EllipsisComponent;
}());
export { EllipsisComponent };
//# sourceMappingURL=ellipsis.component.js.map